<?php
require_once ('interfaces/VirusFilter.php');
require_once ('kavmng.php' );

class kavFilter implements VirusFilter
{
	public function getName()
	{
		return 'Kaspersky AntiVirus';
	}

	public function getUserController(User $user)
	{
		static $cache = array();

		if ($user->getType() != IS_MAIL_USER)
		return null;

		if (!isset($cache[$user->getId()])) {
			$cache[$user->getId()] = new kavVirusFilterUserController($user);
		}
		return $cache[$user->getId()];
	}


	public function applyStatus($status)
	{
		static $status_cmds = array(
			VirusFilter::STATUS_ON => "on",
			VirusFilter::STATUS_OFF => "off");

		$mng = new kavmng();
		$mng->cmd(array($status_cmds[$status]));
	}

	public function available()
	{
		return kavmng::key_installed();
	}
}

class kavVirusFilterUserController extends VirusFilterUserController {

	function getAllMails()
	{
		$user = $this->user;

		$domain = $user->getDomain();
		$dom_id = $domain->getId();

		$domainnames = kavmng::getAllDomains($dom_id, $domain->getDisplayName());
		
		$mailname = $user->getMailName();
		$mailnames = mail_Facade::getInstance()->getMailAliases($mailname->getId());
		$mailnames[] = $mailname->getMailname();

		$rv = array();
		foreach ($domainnames as $dname) {
			foreach ($mailnames as $mname) {
				$rv[ $mname . '@' . $dname ] = $mailname->getId();
			}
		}
		return $rv;
	}

	public function applyStatus($status) {
		$mng = new kavmng();
		$allmails = $this->getAllMails();
		foreach ($allmails as $maddr => $maddr_id) {
			$mng->applyStatus($status, $maddr, $maddr_id);
		}
	}
}

return array ('kav' => new kavFilter());

?>
